==> rendition-9.4.0.tgz: package/dist_esm5/extra/Form/markdown.js <==
import * as tslib_1 from "tslib";
import { Tab, Tabs } from 'grommet';
import * as React from 'react';
import { Link, Textarea, Theme } from '../../';
import { Form } from '../../unstable';
import { Markdown } from '../Markdown';
var Widget = (function (_super) {
    tslib_1.__extends(Widget, _super);
    function Widget() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.handleChange = function (_a) {
            var value = _a.target.value;
            return _this.props.onChange(value === '' ? _this.props.options.emptyValue : value);
        };
        _this.handleBlur = function (event) {
            if (_this.props.onBlur) {
                _this.props.onBlur(_this.props.id, event.target.value);
            }
        };
        _this.handleFocus = function (event) {
            if (_this.props.onFocus) {
                _this.props.onFocus(_this.props.id, event.target.value);
            }
        };
        return _this;
    }
    Widget.prototype.render = function () {
        var _a = this.props, value = _a.value, readonly = _a.readonly, disabled = _a.disabled, autofocus = _a.autofocus, onBlur = _a.onBlur, onFocus = _a.onFocus, options = _a.options, schema = _a.schema, formContext = _a.formContext, inputProps = tslib_1.__rest(_a, ["value", "readonly", "disabled", "autofocus", "onBlur", "onFocus", "options", "schema", "formContext"]);
        return (React.createElement(React.Fragment, null,
            React.createElement(Tabs, { justify: "start" },
                React.createElement(Tab, { title: "Write" },
                    React.createElement(Textarea, tslib_1.__assign({ placeholder: "This text supports markdown", readOnly: readonly, disabled: disabled, autoFocus: autofocus, value: value || '' }, inputProps, { onChange: this.handleChange, onBlur: this.handleBlur, onFocus: this.handleFocus, rows: 5 }))),
                React.createElement(Tab, { title: "Preview" },
                    React.createElement(Markdown, { p: 3, style: {
                            borderRadius: Theme.radius,
                            width: '100%',
                            minHeight: 180,
                        } }, value))),
            React.createElement(Link, { fontSize: 0, href: 'https://guides.github.com/features/mastering-markdown/', blank: true }, "About markdown")));
    };
    return Widget;
}(React.Component));
Form.registerWidget('markdown', Widget);

==> rendition-11.10.0.tgz: package/dist_esm5/extra/Form/markdown.js <==
import * as tslib_1 from "tslib";
import { Tab, Tabs } from 'grommet';
import * as React from 'react';
import { Link, Textarea, Theme } from '../../';
import { Markdown } from '../Markdown';
var MarkdownWidget = (function (_super) {
    tslib_1.__extends(MarkdownWidget, _super);
    function MarkdownWidget() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.handleChange = function (_a) {
            var value = _a.target.value;
            return _this.props.onChange(value === '' ? _this.props.options.emptyValue : value);
        };
        _this.handleBlur = function (event) {
            if (_this.props.onBlur) {
                _this.props.onBlur(_this.props.id, event.target.value);
            }
        };
        _this.handleFocus = function (event) {
            if (_this.props.onFocus) {
                _this.props.onFocus(_this.props.id, event.target.value);
            }
        };
        return _this;
    }
    MarkdownWidget.prototype.render = function () {
        var _a = this.props, value = _a.value, readonly = _a.readonly, disabled = _a.disabled, autofocus = _a.autofocus, onBlur = _a.onBlur, onFocus = _a.onFocus, options = _a.options, schema = _a.schema, formContext = _a.formContext, inputProps = tslib_1.__rest(_a, ["value", "readonly", "disabled", "autofocus", "onBlur", "onFocus", "options", "schema", "formContext"]);
        return (React.createElement(React.Fragment, null,
            React.createElement(Tabs, { justify: "start" },
                React.createElement(Tab, { title: "Write" },
                    React.createElement(Textarea, tslib_1.__assign({ placeholder: "This text supports markdown", readOnly: readonly, disabled: disabled, autoFocus: autofocus, value: value || '' }, inputProps, { onChange: this.handleChange, onBlur: this.handleBlur, onFocus: this.handleFocus, rows: 5 }))),
                React.createElement(Tab, { title: "Preview" },
                    React.createElement(Markdown, { p: 3, style: {
                            borderRadius: Theme.radius,
                            width: '100%',
                            minHeight: 180,
                        } }, value))),
            React.createElement(Link, { fontSize: 0, href: 'https://guides.github.com/features/mastering-markdown/', blank: true }, "About markdown")));
    };
    return MarkdownWidget;
}(React.Component));
export { MarkdownWidget };
